@@ -15,9 +15,10 @@ from scipy.signal import convolve2d
 
 from .._typing import CHData, Picks
 from ..segmentation import EpochsSegmentation, RawSegmentation
-from ..utils import _compare_infos, _corr_vectors
+from ..utils import _corr_vectors
 from ..utils._checks import (
     _check_n_jobs,
+    _check_picks_uniqueness,
     _check_reject_by_annotation,
     _check_tmin_tmax,
     _check_type,
@@ -168,25 +169,47 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         assert self._fitted_data is not None
         assert self._labels_ is not None
 
+    def _check_unfitted(self):
+        """Check if the cluster is unfitted."""
+        if self.fitted:
+            raise RuntimeError(
+                "Clustering algorithm must be unfitted before using "
+                f"{self.__class__.__name__}. You can set the property "
+                "'.fitted' to False if you want to remove the instance fit."
+            )
+        # sanity-check
+        assert self._cluster_centers_ is None
+        assert self._info is None
+        assert self._fitted_data is None
+        assert self._labels_ is None
+
     @abstractmethod
     @fill_doc
     def fit(
         self,
         inst: Union[BaseRaw, BaseEpochs, CHData],
-        picks: Picks = None,
+        picks: Picks = "eeg",
         tmin: Optional[Union[int, float]] = None,
         tmax: Optional[Union[int, float]] = None,
         reject_by_annotation: bool = True,
         n_jobs: int = 1,
     ) -> NDArray[float]:
-        """Segment `~mne.io.Raw` or `~mne.Epochs` into microstate sequence.
+        """Compute cluster centers.
 
         Parameters
         ----------
-        inst : Raw | Epochs
-            MNE `~mne.io.Raw` or `~mne.Epochs` object containing data to
-            transform to cluster-distance space (absolute spatial correlation).
-        %(picks_all)s
+        inst : Raw | Epochs | ChData
+            MNE `~mne.io.Raw`, `~mne.Epochs` or `~pycrostates.io.ChData` object
+            from which to extract :term:`cluster centers`.
+        picks : str | list | slice | None
+            Channels to include. Note that all channels selected must have the
+            same type. Slices and lists of integers will be interpreted as
+            channel indices. In lists, channel name strings (e.g.
+            ``['Fp1', 'Fp2']``) will pick the given channels. Can also be the
+            string values “all” to pick all channels, or “data” to pick data
+            channels. ``"eeg"`` (default) will pick all eeg channels.
+            Note that channels in ``info['bads']`` will be included if their
+            names or indices are explicitly provided.
         %(tmin_raw)s
         %(tmax_raw)s
         %(reject_by_annotation_raw)s
@@ -194,6 +217,7 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         """
         from ..io import ChData, ChInfo
 
+        self._check_unfitted()
         n_jobs = _check_n_jobs(n_jobs)
         _check_type(inst, (BaseRaw, BaseEpochs, ChData), item_name="inst")
         if isinstance(inst, (BaseRaw, BaseEpochs)):
@@ -203,29 +227,29 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
                 reject_by_annotation
             )
 
-        # retrieve info
-        info = inst.info
-
         # picks
-        picks_bads_inc = _picks_to_idx(info, picks, none="all", exclude=[])
-        picks = _picks_to_idx(info, picks, none="all", exclude="bads")
+        picks_bads_inc = _picks_to_idx(
+            inst.info, picks, none="all", exclude=[]
+        )
+        picks = _picks_to_idx(inst.info, picks, none="all", exclude="bads")
+        _check_picks_uniqueness(inst.info, picks)
         ch_not_used = set(picks_bads_inc) - set(picks)
         if len(ch_not_used) != 0:
             if len(ch_not_used) == 1:
                 msg = (
-                    "Channel %s is set as bad and ignored. To include "
-                    + "it, either remove it from 'inst.info['bads'] or "
-                    + "provide its name explicitly in the 'picks' argument."
+                    "The channel %s is set as bad and ignored. To include "
+                    "it, either remove it from inst.info['bads'] or "
+                    "provide it explicitly in the 'picks' argument."
                 )
             else:
                 msg = (
-                    "Channels %s are set as bads and ignored. To "
-                    + "include them, either remove them from "
-                    + "'inst.info['bads'] or provide their names "
-                    + "explicitly in the 'picks' argument."
+                    "The channels %s are set as bads and ignored. To "
+                    "include them, either remove them from "
+                    "inst.info['bads'] or provide them "
+                    "explicitly in the 'picks' argument."
                 )
             logger.warning(
-                msg, ", ".join(info["ch_names"][k] for k in ch_not_used)
+                msg, ", ".join(inst.info["ch_names"][k] for k in ch_not_used)
             )
             del msg
 
@@ -242,9 +266,22 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
             data = data.reshape(data.shape[0], -1)
 
         # store picks and info
-        self._info = ChInfo(info=pick_info(info, picks_bads_inc))
+        info = pick_info(inst.info, picks, copy=True)
+        if info["bads"] != []:
+            if len(info["bads"]) == 1:
+                msg = (
+                    "The channel %s is set as bad and will be used for "
+                    "fitting."
+                )
+            else:
+                msg = (
+                    "The channels %s are set as bad and will be used for "
+                    "fitting."
+                )
+            logger.warning(msg, ", ".join(ch_name for ch_name in info["bads"]))
+            del msg
+        self._info = ChInfo(info=info)
         self._fitted_data = data
-
         return data
 
     def rename_clusters(
@@ -423,7 +460,7 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
             NDArray[bool],
         ],
     ) -> None:
-        """Invert map polarities for visualisation purposes.
+        """Invert map polarities.
 
         Parameters
         ----------
@@ -435,6 +472,11 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         Notes
         -----
         Operates in-place.
+
+        Inverting polarities has no effect on the other steps
+        of the analysis as polarity is ignored in the current methodology.
+        This function is only used for tuning visualization
+        (i.e. for visual inspection and/or to generate figure for an article).
         """
         self._check_fit()
 
@@ -467,17 +509,20 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
             if invert[k]:
                 self._cluster_centers_[k] = -cluster
 
-    def plot(self, axes: Optional[Axes] = None, *, block: bool = False):
+    @fill_doc
+    def plot(
+        self, axes: Optional[Axes] = None, *, block: bool = False, **kwargs
+    ):
         """
         Plot cluster centers as topographic maps.
 
         Parameters
         ----------
-        axes : Axes | None
-            Either none to create a new figure or axes (or an array of axes)
-            on which the topographic map should be plotted.
-        block : bool
-            Whether to halt program execution until the figure is closed.
+        %(axes_topo)s
+        %(block)s
+        **kwargs
+            Additional keyword arguments are passed to
+            :func:`mne.viz.plot_topomap`.
 
         Returns
         -------
@@ -493,6 +538,7 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
             self._cluster_names,
             axes,
             block=block,
+            **kwargs,
         )
 
     @abstractmethod
@@ -514,7 +560,7 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         inst: Union[BaseRaw, BaseEpochs],
         picks: Picks = None,
         factor: int = 0,
-        half_window_size: int = 3,
+        half_window_size: int = 1,
         tol: Union[int, float] = 10e-6,
         min_segment_length: int = 0,
         reject_edges: bool = True,
@@ -522,20 +568,34 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         *,
         verbose: Optional[str] = None,
     ):
-        """Segment `~mne.io.Raw` or `~mne.Epochs` into microstate sequence.
+        r"""Segment `~mne.io.Raw` or `~mne.Epochs` into microstate sequence.
+
+        Segment instance into microstate sequence using the segmentation
+        smoothing algorithm\ :footcite:p:`Marqui1995`.
 
         Parameters
         ----------
         inst : Raw | Epochs
             MNE `~mne.io.Raw` or `~mne.Epochs` object containing the data to
             use for prediction.
-        %(picks_all)s
+        picks : str | list | slice | None
+            Channels to include. Note that all channels selected must have the
+            same type. Slices and lists of integers will be interpreted as
+            channel indices. In lists, channel name strings (e.g.
+            ``['Fp1', 'Fp2']``) will pick the given channels.
+            Can also be the string values “all” to pick all channels, or “data”
+            to pick data channels. ``None`` (default) will pick all channels
+            used during fitting (e.g., ``self.info['ch_names']``).
+            Note that channels in ``info['bads']`` will be included if their
+            names or indices are explicitly provided.
         factor : int
             Factor used for label smoothing. ``0`` means no smoothing.
+            Default to 0.
         half_window_size : int
             Number of samples used for the half window size while smoothing
-            labels. Has no ffect if ``factor=0``. The half window size is
-            defined as ``window_size = 2 * half_window_size + 1``.
+            labels. The half window size is defined as
+            ``window_size = 2 * half_window_size + 1``. It has no effect if
+            ``factor=0`` (default). Default to 1.
         tol : float
             Convergence tolerance.
         min_segment_length : int
@@ -543,17 +603,21 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
             this value, it will be recursively reasigned to neighbouring
             segments based on absolute spatial correlation.
         reject_edges : bool
-            If True, set first and last segments to unlabeled.
+            If ``True``, set first and last segments to unlabeled.
         %(reject_by_annotation_raw)s
         %(verbose)s
 
         Returns
         -------
-        segmentation : `RawSegmentation` | `EpochsSegmentation`
+        segmentation : RawSegmentation | EpochsSegmentation
             Microstate sequence derivated from instance data. Timepoints are
-            labeled according to cluster centers number: 0 for the first
-            center, 1 for the second, etc..
-            -1 is used for unlabeled time points.
+            labeled according to cluster centers number: ``0`` for the first
+            center, ``1`` for the second, etc..
+            ``-1`` is used for unlabeled time points.
+
+        References
+        ----------
+        .. footbibliography::
         """
         # TODO: reject_by_annotation_raw doc probably doesn't match the correct
         # argument types.
@@ -583,40 +647,115 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         elif reject_by_annotation is None:
             reject_by_annotation = False
 
-        # check that the instance as the required channels (good + bads)
-        # inst_info must have all the channels present in cluster_info
-        _compare_infos(cluster_info=self._info, inst_info=inst.info)
-        picks_ = _picks_to_idx(inst.info, picks, none="all", exclude="bads")
-        ch_ = [
-            ch
-            for k, ch in enumerate(inst.info["ch_names"])
-            if k in picks_ and ch in self._info["bads"]
-        ]
-        if 1 == len(ch_):
+        # warn if bad channels in self._info['bads']
+        if self._info["bads"] != []:
+            if len(self._info["bads"]) == 1:
+                msg = (
+                    "The current fit contains bad channel %s"
+                    + " which will be used for prediction."
+                )
+            else:
+                msg = (
+                    "The current fit contains bad channels %s"
+                    + " which will be used for prediction."
+                )
             logger.warning(
-                "Picked channel %s was set as "
-                "bads during fitting and will be ignored.",
-                ch_[0],
-            )
-        elif 1 < len(ch_):
-            logger.warning(
-                "Picked channels %s were set as "
-                "bads during fitting and will be ignored.",
-                ", ".join(ch_),
+                msg, ", ".join(ch_name for ch_name in self._info["bads"])
             )
+            del msg
 
-        # remove channels that were bads during fitting from picks
-        picks_ = [
-            ch
-            for k, ch in enumerate(inst.info["ch_names"])
-            if k in picks_ and ch not in self._info["bads"]
-        ]
-        picks_data = _picks_to_idx(inst.info, picks_, none="all", exclude=[])
-        good_channels = [
-            ch for ch in self._info["ch_names"] if ch not in self._info["bads"]
-        ]
-        picks_cluster_centers = np.array(
-            [good_channels.index(ch) for ch in picks_]
+        # check that the instance as the required channels (good + bads)
+        # inst.info must have all the channels that were used for fitting and
+        # are saved in self._info
+        picks = self._info["ch_names"] if picks is None else picks
+        picks = _picks_to_idx(inst.info, picks, none="all", exclude="bads")
+        info = pick_info(inst.info, sel=picks, copy=True)
+
+        # look for channels used during fit that are missing in the selected
+        # channels from instance
+        missing_ch = set(self._info["ch_names"]) - set(info["ch_names"])
+        # check if the missing channels are present in instance and are not
+        # selected by the provided picks
+        missing_existing_channel = missing_ch & set(inst.ch_names)
+        missing_non_existing_channel = missing_ch - missing_existing_channel
+
+        # error for required channels missing from the provided instance
+        if len(missing_non_existing_channel) != 0:
+            missing_non_existing_channel = list(missing_non_existing_channel)
+            if len(missing_non_existing_channel) == 1:
+                msg = (
+                    f"The channel {missing_non_existing_channel[0]} was used "
+                    "during fitting but is missing from the provided instance."
+                )
+            else:
+                msg = (
+                    f"The channels {missing_non_existing_channel} were used "
+                    "during fitting but are missing from the provided "
+                    "instance."
+                )
+            raise ValueError(msg)
+
+        # error for required channels not picked from the provided instance
+        if len(missing_existing_channel) != 0:
+            missing_existing_channel = list(missing_existing_channel)
+            if len(missing_existing_channel) == 1:
+                msg = (
+                    f"The channel {missing_existing_channel[0]} is required "
+                    "to predict because it was included during fitting. The "
+                    "provided 'picks' argument does not select "
+                    f"{missing_existing_channel[0]}. To include it, either "
+                    "remove it from inst.info['bads'] or provide its name or "
+                    "indice explicitly in the 'picks' argument."
+                )
+            else:
+                msg = (
+                    f"The channels {missing_existing_channel} are required "
+                    " to predict because they were included during fitting. "
+                    "The provided 'picks' argument does not select "
+                    f"{missing_existing_channel}. To include then, either "
+                    "remove them from inst.info['bads'] or provide their "
+                    "names or indices explicitly in the 'picks' argument."
+                )
+            raise ValueError(msg)
+
+        # unused channel(s), present in inst.info but not present in self._info
+        unused_ch = set(info["ch_names"]) - set(self._info["ch_names"])
+        if len(unused_ch) != 0:
+            if len(unused_ch) == 1:
+                msg = (
+                    "The provided instance and the 'picks' argument results "
+                    "in the selection of %s which was not used during "
+                    "fitting. Thus, it will not be used for prediction."
+                )
+            else:
+                msg = (
+                    "The provided instance and the 'picks' argument results "
+                    "in the selection of %s which were not used during "
+                    "fitting. Thus, they will not be used for prediction."
+                )
+            logger.warning(msg, ", ".join(ch_name for ch_name in unused_ch))
+            del msg
+
+        # check and warn if bad channels have been selected
+        if len(info["bads"]) != 0:
+            if len(info["bads"]) == 1:
+                msg = (
+                    "The channel %s is set as bad in the instance but was "
+                    "selected. It will be used for prediction."
+                )
+            else:
+                msg = (
+                    "The channels %s are set as bad in the instance but were "
+                    "selected. They will be used for prediction."
+                )
+            logger.warning(msg, ", ".join(ch_name for ch_name in info["bads"]))
+            del msg
+
+        # the check before made sure the instance and self had the same channel
+        # selected for both the fitting and the prediction. To ensure the same
+        # pick order between self and instance, we use self._info["ch_names"].
+        picks_data = _picks_to_idx(
+            inst.info, self._info["ch_names"], none="all", exclude=[]
         )
 
         # logging messages
@@ -641,7 +780,6 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
             segmentation = self._predict_raw(
                 inst,
                 picks_data,
-                picks_cluster_centers,
                 factor,
                 tol,
                 half_window_size,
@@ -653,7 +791,6 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
             segmentation = self._predict_epochs(
                 inst,
                 picks_data,
-                picks_cluster_centers,
                 factor,
                 tol,
                 half_window_size,
@@ -666,7 +803,6 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         self,
         raw: BaseRaw,
         picks_data: NDArray[int],
-        picks_cluster_centers: NDArray[int],
         factor: int,
         tol: Union[int, float],
         half_window_size: int,
@@ -688,28 +824,24 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         data = raw.get_data(picks=picks_data)
         # retrieve cluster_centers_ for picks
         cluster_centers_ = deepcopy(self._cluster_centers_)
-        cluster_centers_ = cluster_centers_[:, picks_cluster_centers]
 
         if reject_by_annotation:
             # retrieve onsets/ends for BAD annotations
-            onsets, ends = _annotations_starts_stops(raw, ["BAD"])
-            onsets = onsets.tolist() + [data.shape[-1] - 1]
-            ends = [0] + ends.tolist()
-
+            onsets, ends = _annotations_starts_stops(raw, ["BAD"], invert=True)
             segmentation = np.full(data.shape[-1], -1)
 
             for onset, end in zip(onsets, ends):
                 # small segments can't be smoothed
-                if factor != 0 and onset - end < 2 * half_window_size + 1:
+                if factor != 0 and end - onset < 2 * half_window_size + 1:
                     continue
 
-                data_ = data[:, end:onset]
+                data_ = data[:, onset:end]
                 segment = _BaseCluster._segment(
                     data_, cluster_centers_, factor, tol, half_window_size
                 )
                 if reject_edges:
                     segment = _BaseCluster._reject_edge_segments(segment)
-                segmentation[end:onset] = segment
+                segmentation[onset:end] = segment
 
         else:
             segmentation = _BaseCluster._segment(
@@ -736,7 +868,6 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         self,
         epochs: BaseEpochs,
         picks_data: NDArray[int],
-        picks_cluster_centers: NDArray[int],
         factor: int,
         tol: Union[int, float],
         half_window_size: int,
@@ -756,7 +887,6 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         data = epochs.get_data(picks=picks_data)
         # retrieve cluster_centers_ for picks
         cluster_centers_ = deepcopy(self._cluster_centers_)
-        cluster_centers_ = cluster_centers_[:, picks_cluster_centers]
 
         segments = []
         for epoch_data in data:
@@ -825,11 +955,11 @@ class _BaseCluster(ABC, ChannelsMixin, ContainsMixin, MontageMixin):
         References
         ----------
         .. [1] R. D. Pascual-Marqui, C. M. Michel and D. Lehmann.
-            Segmentation of brain electrical activity into microstates:
-            model estimation and validation.
-            IEEE Transactions on Biomedical Engineering,
-            vol. 42, no. 7, pp. 658-665, July 1995,
-            https://doi.org/10.1109/10.391164.
+               Segmentation of brain electrical activity into microstates:
+               model estimation and validation.
+               IEEE Transactions on Biomedical Engineering,
+               vol. 42, no. 7, pp. 658-665, July 1995,
+               https://doi.org/10.1109/10.391164.
         """
         Ne, Nt = data.shape
         Nu = states.shape[0]
