@@ -7,10 +7,16 @@ from typing import List, Optional, Tuple, Union
 import numpy as np
 from mne.io import Info
 from mne.io.constants import FIFF
-from mne.io.meas_info import _check_bads, _check_ch_keys, _unique_channel_names
+from mne.io.meas_info import (
+    _check_bads,
+    _check_ch_keys,
+    _check_dev_head_t,
+    _unique_channel_names,
+)
 from mne.io.pick import get_channel_type_constants
 from mne.io.proj import Projection
 from mne.io.tag import _ch_coord_dict
+from mne.transforms import Transform
 
 from .._typing import CHInfo
 from ..utils._checks import _check_type, _IntLike
@@ -20,12 +26,15 @@ from ..utils._logs import logger
 class ChInfo(CHInfo, Info):
     """Atemporal measurement information.
 
-    Similar to a mne.Info class, but without any temporal information. Only the
-    channel-related information are present. A ChInfo can be created either:
-        - by providing an `~mne.Info` class from which information are
-          retrieved.
-        - by providing the ``ch_names`` and the ``ch_types`` to create a new
-          instance.
+    Similar to a :class:`mne.Info` class, but without any temporal information.
+    Only the channel-related information are present. A
+    :class:`~pycrostates.io.ChInfo` can be created either:
+
+    - by providing a :class:`~mne.Info` class from which information are
+      retrieved.
+    - by providing the ``ch_names`` and the ``ch_types`` to create a new
+      instance.
+
     Only one of those 2 methods should be used at once.
 
     .. warning:: The only entry that should be manually changed by the user
@@ -36,7 +45,7 @@ class ChInfo(CHInfo, Info):
 
     Parameters
     ----------
-    info : mne.Info | None
+    info : Info | None
         MNE measurement information instance from which channel-related
         variables are retrieved.
     ch_names : list of str | int | None
@@ -58,10 +67,18 @@ class ChInfo(CHInfo, Info):
     comps : list of dict
         CTF software gradient compensation data.
         See Notes for more information.
+    ctf_head_t : dict | None
+        The transformation from 4D/CTF head coordinates to Neuromag head
+        coordinates. This is only present in 4D/CTF data.
     custom_ref_applied : int
         Whether a custom (=other than average) reference has been applied to
         the EEG data. This flag is checked by some algorithms that require an
         average reference to be set.
+    dev_ctf_t : dict | None
+        The transformation from device coordinates to 4D/CTF head coordinates.
+        This is only present in 4D/CTF data.
+    dev_head_t : dict | None
+        The device to head transformation.
     dig : tuple of dict | None
         The Polhemus digitization data in head coordinates.
         See Notes for more information.
@@ -155,9 +172,12 @@ class ChInfo(CHInfo, Info):
         "comps": "comps cannot be set directly. "
                  "Please use method Raw.apply_gradient_compensation() "
                  "instead.",
+        "ctf_head_t": "ctf_head_t cannot be set directly.",
         "custom_ref_applied": "custom_ref_applied cannot be set directly. "
                               "Please use method inst.set_eeg_reference() "
                               "instead.",
+        "dev_ctf_t": "dev_ctf_t cannot be set directly.",
+        "dev_head_t": _check_dev_head_t,
         "dig": "dig cannot be set directly. "
                "Please use method inst.set_montage() instead.",
         "nchan": "nchan cannot be set directly. "
@@ -205,12 +225,17 @@ class ChInfo(CHInfo, Info):
 
     def _init_from_info(self, info: Info):
         """Init instance from mne Info."""
-        self["custom_ref_applied"] = info["custom_ref_applied"]
-        self["bads"] = info["bads"]
+        self["custom_ref_applied"] = info.get(
+            "custom_ref_applied", FIFF.FIFFV_MNE_CUSTOM_REF_OFF
+        )
+        self["bads"] = info.get("bads", [])
         self["chs"] = info["chs"]
-        self["dig"] = info["dig"]
-        self["comps"] = info["comps"]
-        self["projs"] = info["projs"]
+        self["ctf_head_t"] = info.get("ctf_head_t", None)
+        self["dev_ctf_t"] = info.get("dev_ctf_t", None)
+        self["dev_head_t"] = info.get("dev_head_t", Transform("meg", "head"))
+        self["dig"] = info.get("dig", None)
+        self["comps"] = info.get("comps", [])
+        self["projs"] = info.get("projs", [])
         self._update_redundant()
 
     def _init_from_channels(
@@ -248,6 +273,11 @@ class ChInfo(CHInfo, Info):
         # init empty bads
         self["bads"] = []  # mutable, as this can be changed by the user
 
+        # init empty coordinate transformation
+        self["ctf_head_t"] = None
+        self["dev_ctf_t"] = None
+        self["dev_head_t"] = Transform("meg", "head")
+
         # create chs information
         self["chs"] = []
         ch_types_dict = get_channel_type_constants(include_defaults=True)
@@ -282,9 +312,6 @@ class ChInfo(CHInfo, Info):
             )
             self["chs"].append(chan_info)
 
-        # convert to immutable
-        self["chs"] = self["chs"]
-
         # add empty dig
         self["dig"] = None
 
@@ -343,7 +370,12 @@ class ChInfo(CHInfo, Info):
             if self["custom_ref_applied"] != other["custom_ref_applied"]:
                 return False
 
-            # TODO: Compare projs and compensation grades.
+            # compare coordinate transformation
+            for transform in ("ctf_head_t", "dev_ctf_t", "dev_head_t"):
+                if self[transform] != other[transform]:
+                    return False
+
+            # TODO: compare compensation grades and projs
 
             if self["bads"] != other["bads"]:
                 logger.warning("Both info do not have the same bad channels.")
